@@ -1,8 +1,8 @@
-from six.moves import http_client
-from test.tests import FunctionalTest
+from http import client as http_client
 import json
+
 import pecan
-import six
+from test.tests import FunctionalTest
 
 
 used_status_codes = [400, 401, 403, 404, 500]
@@ -240,8 +240,5 @@ class TestWS(FunctionalTest):
         assert book['author']['id'] == 1
 
     def test_no_content_type_if_no_return_type(self):
-        if six.PY3:
-            self.skipTest(
-                "This test does not work in Python 3 until https://review.openstack.org/#/c/48439/ is merged")
         res = self.app.delete('/authors/4')
         assert "Content-Type" not in res.headers, res.headers['Content-Type']
