@@ -1,5 +1,3 @@
-import six
-
 from wsme.utils import _
 
 
@@ -14,10 +12,10 @@ class ClientSideError(RuntimeError):
     def faultstring(self):
         if self.msg is None:
             return str(self)
-        elif isinstance(self.msg, six.text_type):
+        elif isinstance(self.msg, str):
             return self.msg
         else:
-            return six.u(self.msg)
+            return str(self.msg)
 
 
 class InvalidInput(ClientSideError):
@@ -28,9 +26,9 @@ class InvalidInput(ClientSideError):
 
     @property
     def faultstring(self):
-        return _(six.u(
-            "Invalid input for field/attribute %s. Value: '%s'. %s")
-        ) % (self.fieldname, self.value, self.msg)
+        return _("Invalid input for field/attribute %s. Value: '%s'. %s") % (
+            self.fieldname, self.value, self.msg,
+        )
 
 
 class MissingArgument(ClientSideError):
@@ -40,8 +38,9 @@ class MissingArgument(ClientSideError):
 
     @property
     def faultstring(self):
-        return _(six.u('Missing argument: "%s"%s')) % (
-            self.argname, self.msg and ": " + self.msg or "")
+        return _('Missing argument: "%s"%s') % (
+            self.argname, self.msg and ": " + self.msg or "",
+        )
 
 
 class UnknownArgument(ClientSideError):
@@ -51,8 +50,9 @@ class UnknownArgument(ClientSideError):
 
     @property
     def faultstring(self):
-        return _(six.u('Unknown argument: "%s"%s')) % (
-            self.argname, self.msg and ": " + self.msg or "")
+        return _('Unknown argument: "%s"%s') % (
+            self.argname, self.msg and ": " + self.msg or "",
+        )
 
 
 class UnknownFunction(ClientSideError):
@@ -62,7 +62,7 @@ class UnknownFunction(ClientSideError):
 
     @property
     def faultstring(self):
-        return _(six.u("Unknown function name: %s")) % (self.name)
+        return _("Unknown function name: %s") % (self.name)
 
 
 class UnknownAttribute(ClientSideError):
