@@ -1,12 +1,10 @@
 """REST+Json protocol implementation."""
-from __future__ import absolute_import
 
 import datetime
 import decimal
 import json
 
 from simplegeneric import generic
-import six
 
 import wsme.exc
 import wsme.types
@@ -180,12 +178,12 @@ def dict_fromjson(datatype, value):
         for item in value.items()))
 
 
-@fromjson.when_object(six.binary_type)
+@fromjson.when_object(bytes)
 def str_fromjson(datatype, value):
-    if (isinstance(value, six.string_types) or
-            isinstance(value, six.integer_types) or
+    if (isinstance(value, str) or
+            isinstance(value, int) or
             isinstance(value, float)):
-        return six.text_type(value).encode('utf8')
+        return str(value).encode('utf8')
 
 
 @fromjson.when_object(wsme.types.text)
@@ -195,7 +193,7 @@ def text_fromjson(datatype, value):
     return value
 
 
-@fromjson.when_object(*six.integer_types + (float,))
+@fromjson.when_object(int, float)
 def numeric_fromjson(datatype, value):
     """Convert string object to built-in types int, long or float."""
     if value is None:
@@ -208,7 +206,7 @@ def bool_fromjson(datatype, value):
     """Convert to bool, restricting strings to just unambiguous values."""
     if value is None:
         return None
-    if isinstance(value, six.integer_types + (bool,)):
+    if isinstance(value, (int, bool,)):
         return bool(value)
     if value in ENUM_TRUE:
         return True
@@ -248,7 +246,7 @@ def datetime_fromjson(datatype, value):
 def parse(s, datatypes, bodyarg, encoding='utf8'):
     jload = json.load
     if not hasattr(s, 'read'):
-        if six.PY3 and isinstance(s, six.binary_type):
+        if isinstance(s, bytes):
             s = s.decode(encoding)
         jload = json.loads
     try:
