@@ -1,11 +1,6 @@
 # encoding=utf8
 
-from six import b
-
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 import webtest
 
 from wsme import WSRoot, expose, validate
@@ -205,7 +200,7 @@ class TestController(unittest.TestCase):
         assert res.status_int == 406
         print(res.body)
         assert res.body.find(
-            b("None of the following protocols can handle this request")) != -1
+            b"None of the following protocols can handle this request") != -1
 
     def test_return_content_type_guess(self):
         class DummierProto(DummyProtocol):
@@ -259,19 +254,19 @@ class TestController(unittest.TestCase):
             'Accept': 'application/json'
         })
 
-        self.assertEqual(res.body, b('10'))
+        self.assertEqual(res.body, b'10')
 
         res = app.get('/mul_float?a=1.2&b=2.9', headers={
             'Accept': 'application/json'
         })
 
-        self.assertEqual(res.body, b('3.48'))
+        self.assertEqual(res.body, b'3.48')
 
         res = app.get('/mul_string?a=hello&b=2', headers={
             'Accept': 'application/json'
         })
 
-        self.assertEqual(res.body, b('"hellohello"'))
+        self.assertEqual(res.body, b'"hellohello"')
 
     def test_wsattr_mandatory(self):
         class ComplexType(object):
