@@ -2,6 +2,7 @@ import base64
 import datetime
 import decimal
 import json
+from urllib.parse import urlencode
 
 from wsme.exc import ClientSideError, InvalidInput
 from wsme.types import isarray, isdict, isusertype, register_type
@@ -11,14 +12,6 @@ from wsme.rest.json import fromjson, tojson, parse
 import wsme.tests.protocol
 from wsme.utils import parse_isodatetime, parse_isotime, parse_isodate
 
-import six
-from six import b, u
-
-if six.PY3:
-    from urllib.parse import urlencode
-else:
-    from urllib import urlencode  # noqa
-
 
 def prepare_value(value, datatype):
     if isinstance(datatype, list):
@@ -35,7 +28,7 @@ def prepare_value(value, datatype):
     if datatype == decimal.Decimal:
         return str(value)
     if datatype == wsme.types.binary:
-        return base64.encodestring(value).decode('ascii')
+        return base64.encodebytes(value).decode('ascii')
     if datatype == wsme.types.bytes:
         return value.decode('ascii')
     return value
@@ -46,7 +39,7 @@ def prepare_result(value, datatype):
     if value is None:
         return None
     if datatype == wsme.types.binary:
-        return base64.decodestring(value.encode('ascii'))
+        return base64.decodebytes(value.encode('ascii'))
     if isusertype(datatype):
         datatype = datatype.basetype
     if isinstance(datatype, list):
@@ -113,21 +106,21 @@ class MiniCrud(object):
     @validate(Obj)
     def create(self, data):
         print(repr(data))
-        return CRUDResult(data, u('create'))
+        return CRUDResult(data, 'create')
 
     @expose(CRUDResult, method='GET', ignore_extra_args=True)
     @validate(Obj)
     def read(self, ref):
         print(repr(ref))
         if ref.id == 1:
-            ref.name = u('test')
-        return CRUDResult(ref, u('read'))
+            ref.name = 'test'
+        return CRUDResult(ref, 'read')
 
     @expose(CRUDResult, method='POST')
     @validate(Obj)
     def update(self, data):
         print(repr(data))
-        return CRUDResult(data, u('update'))
+        return CRUDResult(data, 'update')
 
     @expose(CRUDResult, wsme.types.text, body=Obj)
     def update_with_body(self, msg, data):
@@ -139,8 +132,8 @@ class MiniCrud(object):
     def delete(self, ref):
         print(repr(ref))
         if ref.id == 1:
-            ref.name = u('test')
-        return CRUDResult(ref, u('delete'))
+            ref.name = 'test'
+        return CRUDResult(ref, 'delete')
 
 
 wsme.tests.protocol.WSTestRoot.crud = MiniCrud()
@@ -391,7 +384,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
             assert e.msg == "'%s' is not a legal date value" % jdate
 
     def test_valid_str_to_builtin_fromjson(self):
-        types = six.integer_types + (bool, float)
+        types = (int, bool, float)
         value = '2'
         for t in types:
             for ba in True, False:
@@ -424,7 +417,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
                 self.assertIsInstance(i['a'], float)
 
     def test_invalid_str_to_buitin_fromjson(self):
-        types = six.integer_types + (float, bool)
+        types = (int, float, bool)
         value = '2a'
         for t in types:
             for ba in True, False:
@@ -571,7 +564,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
 
     def test_bytes_tojson(self):
         assert tojson(wsme.types.bytes, None) is None
-        assert tojson(wsme.types.bytes, b('ascii')) == u('ascii')
+        assert tojson(wsme.types.bytes, b'ascii') == 'ascii'
 
     def test_encode_sample_params(self):
         r = wsme.rest.json.encode_sample_params(
@@ -590,7 +583,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         assert r[1] == '''2'''
 
     def test_PUT(self):
-        data = {"id": 1, "name": u("test")}
+        data = {"id": 1, "name": "test"}
         content = json.dumps(dict(data=data))
         headers = {
             'Content-Type': 'application/json',
@@ -604,7 +597,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         result = json.loads(res.text)
         print(result)
         assert result['data']['id'] == 1
-        assert result['data']['name'] == u("test")
+        assert result['data']['name'] == "test"
         assert result['message'] == "create"
 
     def test_GET(self):
@@ -619,7 +612,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         result = json.loads(res.text)
         print(result)
         assert result['data']['id'] == 1
-        assert result['data']['name'] == u("test")
+        assert result['data']['name'] == "test"
 
     def test_GET_complex_accept(self):
         headers = {
@@ -633,7 +626,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         result = json.loads(res.text)
         print(result)
         assert result['data']['id'] == 1
-        assert result['data']['name'] == u("test")
+        assert result['data']['name'] == "test"
 
     def test_GET_complex_choose_xml(self):
         headers = {
@@ -655,10 +648,11 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
             headers=headers,
             status=406)
         print("Received:", res.body)
-        assert res.body == b("Unacceptable Accept type: "
-                             "text/html, application/xml;q=0.9 not in "
-                             "['application/json', 'text/javascript', "
-                             "'application/javascript', 'text/xml']")
+        assert res.body == (
+            b"Unacceptable Accept type: "
+            b"text/html, application/xml;q=0.9 not in "
+            b"['application/json', 'text/javascript', "
+            b"'application/javascript', 'text/xml']")
 
     def test_GET_bad_simple_accept(self):
         headers = {
@@ -669,9 +663,10 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
             headers=headers,
             status=406)
         print("Received:", res.body)
-        assert res.body == b("Unacceptable Accept type: text/plain not in "
-                             "['application/json', 'text/javascript', "
-                             "'application/javascript', 'text/xml']")
+        assert res.body == (
+            b"Unacceptable Accept type: text/plain not in "
+            b"['application/json', 'text/javascript', "
+            b"'application/javascript', 'text/xml']")
 
     def test_POST(self):
         headers = {
@@ -679,14 +674,14 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         }
         res = self.app.post(
             '/crud',
-            json.dumps(dict(data=dict(id=1, name=u('test')))),
+            json.dumps(dict(data=dict(id=1, name='test'))),
             headers=headers,
             expect_errors=False)
         print("Received:", res.body)
         result = json.loads(res.text)
         print(result)
         assert result['data']['id'] == 1
-        assert result['data']['name'] == u("test")
+        assert result['data']['name'] == "test"
         assert result['message'] == "update"
 
     def test_POST_bad_content_type(self):
@@ -695,13 +690,14 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         }
         res = self.app.post(
             '/crud',
-            json.dumps(dict(data=dict(id=1, name=u('test')))),
+            json.dumps(dict(data=dict(id=1, name='test'))),
             headers=headers,
             status=415)
         print("Received:", res.body)
-        assert res.body == b("Unacceptable Content-Type: text/plain not in "
-                             "['application/json', 'text/javascript', "
-                             "'application/javascript', 'text/xml']")
+        assert res.body == (
+            b"Unacceptable Content-Type: text/plain not in "
+            b"['application/json', 'text/javascript', "
+            b"'application/javascript', 'text/xml']")
 
     def test_DELETE(self):
         res = self.app.delete(
@@ -711,7 +707,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         result = json.loads(res.text)
         print(result)
         assert result['data']['id'] == 1
-        assert result['data']['name'] == u("test")
+        assert result['data']['name'] == "test"
         assert result['message'] == "delete"
 
     def test_extra_arguments(self):
@@ -726,7 +722,7 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         result = json.loads(res.text)
         print(result)
         assert result['data']['id'] == 1
-        assert result['data']['name'] == u("test")
+        assert result['data']['name'] == "test"
         assert result['message'] == "read"
 
     def test_unexpected_extra_arg(self):
@@ -762,12 +758,12 @@ class TestRestJson(wsme.tests.protocol.RestOnlyProtocolTestCase):
         }
         res = self.app.post(
             '/crud/update_with_body?msg=hello',
-            json.dumps(dict(id=1, name=u('test'))),
+            json.dumps(dict(id=1, name='test')),
             headers=headers,
             expect_errors=False)
         print("Received:", res.body)
         result = json.loads(res.text)
         print(result)
         assert result['data']['id'] == 1
-        assert result['data']['name'] == u("test")
+        assert result['data']['name'] == "test"
         assert result['message'] == "hello"
