@@ -1,9 +1,5 @@
 import re
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-import six
+import unittest
 
 from wsme import exc
 from wsme import types
@@ -37,8 +33,8 @@ class TestTypes(unittest.TestCase):
     def test_flat_type(self):
         class Flat(object):
             aint = int
-            abytes = six.binary_type
-            atext = six.text_type
+            abytes = bytes
+            atext = str
             afloat = float
 
         types.register_type(Flat)
@@ -228,12 +224,12 @@ Value: 'v3'. Value should be one of: v., v.",
 
         obj = SType()
 
-        obj.atext = six.b('somebytes')
-        assert obj.atext == six.u('somebytes')
+        obj.atext = b'somebytes'
+        assert obj.atext == 'somebytes'
         assert isinstance(obj.atext, types.text)
 
-        obj.abytes = six.u('sometext')
-        assert obj.abytes == six.b('sometext')
+        obj.abytes = 'sometext'
+        assert obj.abytes == b'sometext'
         assert isinstance(obj.abytes, types.bytes)
 
     def test_named_attribute(self):
@@ -303,8 +299,8 @@ Value: 'v3'. Value should be one of: v., v.",
 
     def test_validate_int(self):
         self.assertEqual(types.validate_value(int, 1), 1)
+        self.assertEqual(types.validate_value(int, b'1'), 1)
         self.assertEqual(types.validate_value(int, '1'), 1)
-        self.assertEqual(types.validate_value(int, six.u('1')), 1)
         self.assertRaises(ValueError, types.validate_value, int, 1.1)
 
     def test_validate_integer_type(self):
@@ -440,10 +436,10 @@ Value: 'v3'. Value should be one of: v., v.",
 
     def test_base_init(self):
         class C1(types.Base):
-            s = six.text_type
+            s = str
 
-        c = C1(s=six.u('test'))
-        assert c.s == six.u('test')
+        c = C1(s='test')
+        assert c.s == 'test'
 
     def test_array_eq(self):
         ell = [types.ArrayType(str)]
@@ -464,14 +460,14 @@ Value: 'v3'. Value should be one of: v., v.",
     def test_binary_to_base(self):
         import base64
         assert types.binary.tobasetype(None) is None
-        expected = base64.encodestring(six.b('abcdef'))
-        assert types.binary.tobasetype(six.b('abcdef')) == expected
+        expected = base64.encodebytes(b'abcdef')
+        assert types.binary.tobasetype(b'abcdef') == expected
 
     def test_binary_from_base(self):
         import base64
         assert types.binary.frombasetype(None) is None
-        encoded = base64.encodestring(six.b('abcdef'))
-        assert types.binary.frombasetype(encoded) == six.b('abcdef')
+        encoded = base64.encodebytes(b'abcdef')
+        assert types.binary.frombasetype(encoded) == b'abcdef'
 
     def test_wsattr_weakref_datatype(self):
         # If the datatype inside the wsattr ends up a weakref, it
@@ -551,8 +547,8 @@ Value: 'v3'. Value should be one of: v., v.",
         class buffer:
             def read(self):
                 return 'from-file'
-        f = types.File(content=six.b('from-content'))
-        assert f.file.read() == six.b('from-content')
+        f = types.File(content=b'from-content')
+        assert f.file.read() == b'from-content'
 
     def test_unregister(self):
         class TempType(object):
